@@ -1,11 +1,14 @@
 """Common tooling exceptions. Store them in this central place to
 avoid circular imports
 """
+from __future__ import absolute_import, print_function, unicode_literals
+
 
 class ElliottFatalError(Exception):
     """A broad exception for errors during Brew CRUD operations"""
     pass
 
+
 class BrewBuildException(Exception):
     """A broad exception for errors during Brew CRUD operations"""
     pass
@@ -24,3 +27,8 @@ class ErrataToolUnauthorizedException(Exception):
 class ErrataToolError(Exception):
     """General problem interacting with the Errata Tool"""
     pass
+
+
+class BugzillaFatalError(Exception):
+    """A broad exception for errors during Bugzilla API call"""
+    pass
